
# Find Best Random state  for a model

To find a  Best random state for a model,Regerssor wise .Ity will help you Lot ,simpoly just pass your  below data
- Regerssor name(alias of your Regerssor name)

- x -> the independent variable

- y -> the dependent variable


## Installation
```python
! pip install findr2
```

## Import
```python
from findr2 import find_max_r2
```
## calling function
```
find_max_r2.find_r2(lr,x,y)
#lr=LinearRegression
```
## Authors

- [@Ranjit Maity](https://github.com/RanjitM007)

